==> kmymoney-5.0.7.tar.xz: kmymoney-5.0.7/kmymoney/plugins/qif/export/qifexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx"
            }
        ],
        "Description": "Add QIF exporting to KMyMoney",
        "Description[ca@valencia]": "Afig l'exportació a QIF al KMyMoney",
        "Description[ca]": "Afegeix l'exportació a QIF al KMyMoney",
        "Description[de]": "Fügt QIF-Export zu KMyMoney hinzu",
        "Description[en_GB]": "Add QIF exporting to KMyMoney",
        "Description[es]": "Añade exportación QIF a KMyMoney",
        "Description[fr]": "Ajoute l'exportation « QIF » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de exportar QIF desde KMyMoney",
        "Description[it]": "Aggiunge l'esportazione QIF a KMymoney",
        "Description[ko]": "KMyMoney에 QIF 내보내기 추가",
        "Description[nl]": "Voeg QIF exporteren toe aan KMyMoney",
        "Description[pl]": "Dodaje eksportowanie QIF do KMyMoney",
        "Description[pt]": "Adição da exportação para QIF para o KMyMoney",
        "Description[pt_BR]": "Adiciona exportação QIF no KMyMoney",
        "Description[sv]": "Lägg till QIF-export till KMyMoney",
        "Description[uk]": "Експортування даних QIF у KMyMoney",
        "Description[x-test]": "xxAdd QIF exporting to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-export",
        "Id": "qifexporter",
        "License": "GPL",
        "Name": "QIF Exporter",
        "Name[ca@valencia]": "Exportador a QIF",
        "Name[ca]": "Exportador a QIF",
        "Name[de]": "QIF-Export",
        "Name[en_GB]": "QIF Exporter",
        "Name[es]": "Exportador QIF",
        "Name[fr]": "Exportateur QIF",
        "Name[gl]": "Exportador a QIF",
        "Name[it]": "Strumento di esportazione QIF",
        "Name[nl]": "QIF exporteren",
        "Name[pl]": "Eksporter QIF",
        "Name[pt]": "Exportação para QIF",
        "Name[pt_BR]": "Exportador QIF",
        "Name[sv]": "QIF-export",
        "Name[uk]": "Інструмент експортування QIF",
        "Name[x-test]": "xxQIF Exporterxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.0.8.orig.tar.xz: kmymoney-5.0.8/kmymoney/plugins/qif/export/qifexporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "mte@users.sourceforge.net",
                "Name": "Michael Edwardes",
                "Name[ca@valencia]": "Michael Edwardes",
                "Name[ca]": "Michael Edwardes",
                "Name[cs]": "Michael Edwardes",
                "Name[de]": "Michael Edwardes",
                "Name[en_GB]": "Michael Edwardes",
                "Name[es]": "Michael Edwardes",
                "Name[fr]": "Michael Edwardes",
                "Name[gl]": "Michael Edwardes",
                "Name[it]": "Michael Edwardes",
                "Name[nl]": "Michael Edwardes",
                "Name[pl]": "Michael Edwardes",
                "Name[pt]": "Michael Edwardes",
                "Name[pt_BR]": "Michael Edwardes",
                "Name[ru]": "Michael Edwardes",
                "Name[sk]": "Michael Edwardes",
                "Name[sv]": "Michael Edwardes",
                "Name[uk]": "Michael Edwardes",
                "Name[x-test]": "xxMichael Edwardesxx"
            }
        ],
        "Description": "Add QIF exporting to KMyMoney",
        "Description[ca@valencia]": "Afig l'exportació a QIF al KMyMoney",
        "Description[ca]": "Afegeix l'exportació a QIF al KMyMoney",
        "Description[de]": "Fügt QIF-Export zu KMyMoney hinzu",
        "Description[en_GB]": "Add QIF exporting to KMyMoney",
        "Description[es]": "Añade exportación QIF a KMyMoney",
        "Description[fr]": "Ajoute l'exportation « QIF » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de exportar QIF desde KMyMoney",
        "Description[it]": "Aggiunge l'esportazione QIF a KMymoney",
        "Description[ko]": "KMyMoney에 QIF 내보내기 추가",
        "Description[nl]": "Voeg QIF exporteren toe aan KMyMoney",
        "Description[pl]": "Dodaje eksportowanie QIF do KMyMoney",
        "Description[pt]": "Adição da exportação para QIF para o KMyMoney",
        "Description[pt_BR]": "Adiciona exportação QIF no KMyMoney",
        "Description[sk]": "Pridať QIF export do KMyMoney",
        "Description[sv]": "Lägg till QIF-export till KMyMoney",
        "Description[uk]": "Експортування даних QIF у KMyMoney",
        "Description[x-test]": "xxAdd QIF exporting to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "document-export",
        "Id": "qifexporter",
        "License": "GPL",
        "Name": "QIF Exporter",
        "Name[ca@valencia]": "Exportador a QIF",
        "Name[ca]": "Exportador a QIF",
        "Name[de]": "QIF-Export",
        "Name[en_GB]": "QIF Exporter",
        "Name[es]": "Exportador QIF",
        "Name[fr]": "Exportateur QIF",
        "Name[gl]": "Exportador a QIF",
        "Name[it]": "Strumento di esportazione QIF",
        "Name[nl]": "QIF exporteren",
        "Name[pl]": "Eksporter QIF",
        "Name[pt]": "Exportação para QIF",
        "Name[pt_BR]": "Exportador QIF",
        "Name[ru]": "Экспорт QIF",
        "Name[sk]": "QIF Exporter",
        "Name[sv]": "QIF-export",
        "Name[uk]": "Інструмент експортування QIF",
        "Name[x-test]": "xxQIF Exporterxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
